
From: Russell King <rmk+lkml@arm.linux.org.uk>

This patch cleans up needless includes of asm/pgalloc.h from the drivers/
subtree.  drivers/char/mem.c has been compile tested; the others have not,
since they are for non-x86 and non-ARM architectures.

This patch is part of a larger patch aiming towards getting the include of
asm/pgtable.h out of linux/mm.h, so that asm/pgtable.h can sanely get at
things like mm_struct and friends.

I suggest testing in -mm for a while to ensure there aren't any hidden arch
issues.


---

 25-akpm/drivers/char/mem.c                  |    1 -
 25-akpm/drivers/net/82596.c                 |    1 -
 25-akpm/drivers/net/lasi_82596.c            |    1 -
 25-akpm/drivers/net/macsonic.c              |    1 -
 25-akpm/drivers/net/sun3lance.c             |    1 -
 25-akpm/drivers/parisc/ccio-dma.c           |    1 -
 25-akpm/drivers/parisc/ccio-rm-dma.c        |    1 -
 25-akpm/drivers/video/console/sticore.c     |    1 -
 25-akpm/sound/oss/dmasound/dmasound_atari.c |    1 -
 9 files changed, 9 deletions(-)

diff -puN drivers/char/mem.c~clean-up-asm-pgalloch-include-2 drivers/char/mem.c
--- 25/drivers/char/mem.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.228754312 -0700
+++ 25-akpm/drivers/char/mem.c	2004-04-18 15:24:47.244751880 -0700
@@ -26,7 +26,6 @@
 
 #include <asm/uaccess.h>
 #include <asm/io.h>
-#include <asm/pgalloc.h>
 
 #ifdef CONFIG_IA64
 # include <linux/efi.h>
diff -puN drivers/net/82596.c~clean-up-asm-pgalloch-include-2 drivers/net/82596.c
--- 25/drivers/net/82596.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.230754008 -0700
+++ 25-akpm/drivers/net/82596.c	2004-04-18 15:24:47.245751728 -0700
@@ -58,7 +58,6 @@
 #include <asm/io.h>
 #include <asm/dma.h>
 #include <asm/pgtable.h>
-#include <asm/pgalloc.h>
 
 static char version[] __initdata =
 	"82596.c $Revision: 1.5 $\n";
diff -puN drivers/net/lasi_82596.c~clean-up-asm-pgalloch-include-2 drivers/net/lasi_82596.c
--- 25/drivers/net/lasi_82596.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.232753704 -0700
+++ 25-akpm/drivers/net/lasi_82596.c	2004-04-18 15:24:47.246751576 -0700
@@ -87,7 +87,6 @@
 #include <asm/bitops.h>
 #include <asm/io.h>
 #include <asm/pgtable.h>
-#include <asm/pgalloc.h>
 #include <asm/irq.h>
 #include <asm/pdc.h>
 #include <asm/cache.h>
diff -puN drivers/net/macsonic.c~clean-up-asm-pgalloch-include-2 drivers/net/macsonic.c
--- 25/drivers/net/macsonic.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.233753552 -0700
+++ 25-akpm/drivers/net/macsonic.c	2004-04-18 15:24:47.247751424 -0700
@@ -53,7 +53,6 @@
 #include <asm/macintosh.h>
 #include <asm/macints.h>
 #include <asm/mac_via.h>
-#include <asm/pgalloc.h>
 
 #define SREGS_PAD(n)    u16 n;
 
diff -puN drivers/net/sun3lance.c~clean-up-asm-pgalloch-include-2 drivers/net/sun3lance.c
--- 25/drivers/net/sun3lance.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.235753248 -0700
+++ 25-akpm/drivers/net/sun3lance.c	2004-04-18 15:24:47.247751424 -0700
@@ -42,7 +42,6 @@ static char *version = "sun3lance.c: v1.
 #include <asm/bitops.h>
 #include <asm/io.h>
 #include <asm/pgtable.h>
-#include <asm/pgalloc.h>
 #include <asm/dvma.h>
 #include <asm/idprom.h>
 #include <asm/machines.h>
diff -puN drivers/parisc/ccio-dma.c~clean-up-asm-pgalloch-include-2 drivers/parisc/ccio-dma.c
--- 25/drivers/parisc/ccio-dma.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.236753096 -0700
+++ 25-akpm/drivers/parisc/ccio-dma.c	2004-04-18 15:24:47.249751120 -0700
@@ -44,7 +44,6 @@
 #include <asm/byteorder.h>
 #include <asm/cache.h>		/* for L1_CACHE_BYTES */
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/page.h>
 #include <asm/dma.h>
 #include <asm/io.h>
diff -puN drivers/parisc/ccio-rm-dma.c~clean-up-asm-pgalloch-include-2 drivers/parisc/ccio-rm-dma.c
--- 25/drivers/parisc/ccio-rm-dma.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.237752944 -0700
+++ 25-akpm/drivers/parisc/ccio-rm-dma.c	2004-04-18 15:24:47.249751120 -0700
@@ -40,7 +40,6 @@
 #include <linux/pci.h>
 
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 
 #include <asm/io.h>
 #include <asm/hardware.h>
diff -puN drivers/video/console/sticore.c~clean-up-asm-pgalloch-include-2 drivers/video/console/sticore.c
--- 25/drivers/video/console/sticore.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.239752640 -0700
+++ 25-akpm/drivers/video/console/sticore.c	2004-04-18 15:24:47.250750968 -0700
@@ -22,7 +22,6 @@
 #include <linux/pci.h>
 #include <linux/font.h>
 
-#include <asm/pgalloc.h>
 #include <asm/hardware.h>
 #include <asm/parisc-device.h>
 #include <asm/cacheflush.h>
diff -puN sound/oss/dmasound/dmasound_atari.c~clean-up-asm-pgalloch-include-2 sound/oss/dmasound/dmasound_atari.c
--- 25/sound/oss/dmasound/dmasound_atari.c~clean-up-asm-pgalloch-include-2	2004-04-18 15:24:47.240752488 -0700
+++ 25-akpm/sound/oss/dmasound/dmasound_atari.c	2004-04-18 15:24:47.251750816 -0700
@@ -22,7 +22,6 @@
 #include <linux/spinlock.h>
 #include <linux/interrupt.h>
 
-#include <asm/pgalloc.h>
 #include <asm/uaccess.h>
 #include <asm/atariints.h>
 #include <asm/atari_stram.h>

_
